/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2004 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#ifndef __PACKETDATA_H
#define __PACKETDATA_H

#include "vcprotocol.h"
#include <stdlib.h>
#include <qcstring.h>

class PacketData
{
	private:
		unsigned char data[VY_MAXPACKETSIZE];
		int size;
		bool over; //indicates too long packet data
		
	public:
		PacketData(): size(0), over(false)
		{
			createHeader();
		}

		~PacketData()
		{
		}

		inline void createHeader()
		{
			data[0] = 'X';
			//
			// packet id
			for (int i=1; i<11; i++)
				data[i] = (0x30 + random()%9);
			
			size = 10;
		}

		bool isOk() { return !over; }
		
		void* dataPtr() { return data; }

		unsigned int dataLength() { return size; }
		
		inline PacketData& operator <<(const Q_INT8 c)
		{
			if (size < VY_MAXPACKETSIZE)
				data[size++] = c;
			else
				over = true;
			return *this;
		}

		inline PacketData& operator <<(const QCString &str)
		{
			const int n = str.length();
			if (size + n < VY_MAXPACKETSIZE)
			{
				memcpy(data + size, str.data(), n);
				size += n;
			}
			else
			{
				over = true;
			}
			return *this;
		}

		inline PacketData& operator <<(const QByteArray &array)
		{
			if (size + array.size() < VY_MAXPACKETSIZE)
			{
				memcpy(data + size, array.data(), array.size());
				size += array.size();
			}
			else
			{
				over = true;
			}
			return *this;
		}
			
		//friend PacketData& operator<<(PacketData &p, const UUID &uuid);
};

/*inline PacketData& operator<<(PacketData &p, const UUID &uuid)
{
	if (p.size + UUID_LEN < VY_MAXPACKETSIZE)
	{
		memcpy(p.data + p.size, uuid.bytes, UUID_LEN);
		p.size += UUID_LEN;
	}
	else
	{
		p.over = true;
	}
	
	return p;
}*/

#endif

